`xoutil.values`:mod: -- coercers (or checkers) for value types
==============================================================

.. automodule:: xoutil.values
   :members:

Contents:

.. toctree::
   :maxdepth: 1
   :glob:

   values/*
